@@ -1,6 +1,9 @@
-from .make_docker_job import make_docker_job
-from .submit_docker_job import submit_docker_job
 from .check_docker_job import check_docker_job
-from .terminate_docker_job import terminate_docker_job
-from .get_docker_logs import get_docker_logs
 from .clean_docker_job import clean_docker_job
+from .create_docker_volume import create_docker_volume
+from .get_docker_logs import get_docker_logs
+from .make_docker_job import make_docker_job
+from .remove_docker_volume import remove_docker_volume
+from .run_docker_command import run_docker_command
+from .submit_docker_job import submit_docker_job
+from .terminate_docker_job import terminate_docker_job
